<?php

declare(strict_types=1);

namespace BitBag\SyliusBonusPointsPlugin\Form\Type\Rule;

use BitBag\SyliusBonusPointsPlugin\Entity\BonusPointsStrategyInterface;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\HiddenType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\Validator\Constraints\NotBlank;

final class AppliedOnceConfigurationType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add('strategyCode', HiddenType::class, [
                'constraints' => [
                    new NotBlank(),
                ],
            ])
        ;

        $builder->addEventListener(FormEvents::PRE_SUBMIT, function (FormEvent $event) {
            /** @var BonusPointsStrategyInterface $bonusPointsStrategy */
            $bonusPointsStrategy = $event->getForm()->getRoot()->getData();
            $code = $bonusPointsStrategy->getCode();
            $configuration = $event->getData();
            $configuration['strategyCode'] = $code;
            $event->setData($configuration);
        });
    }

    public function getBlockPrefix(): string
    {
        return 'bitbag_bonus_points_strategy_rule_has_taxon_configuration';
    }
}
